@@ -27,9 +27,3 @@ def retry(max_retries=3):
         return wrapper
 
     return retry_dec
-
-
-# Example usage
-@retry(max_retries=2)
-def unpredictable():
-    pass
